#
# spec file for package golang-org-x
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         golang
%global repo            tools
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     golang.org/x/tools

Name:           golang-org-x-%{repo}
Version:        1.4.2+git20161212.0a14ca4
Release:        6.1
Summary:        Additional toolsgraphy libraries
License:        BSD-3-Clause
Group:          Development/Languages/Golang
Url:            https://%{provider_prefix}
Source0:        %{repo}-%{version}.tar.xz
Source1:        rpmlintrc
Source2:        godoc.service
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  fdupes
BuildRequires:  find
BuildRequires:  golang-packaging
BuildRequires:  mango-doc
BuildRequires:  systemd
BuildRequires:  xz

BuildRequires:  golang-org-x-net-html
Requires:       golang-org-x-net-html
BuildRequires:  golang-org-x-net-websocket
Requires:       golang-org-x-net-websocket

%{go_nostrip}
%{go_provides}

%description
This package contains additional toolsgraphy libraries that are developed by the
Go team but outside of the main source tree.

%package -n go-tools
Summary:        Additional toolsgraphy libraries
Group:          Development/Languages/Golang
AutoReqProv:    Off

%{?systemd_requires}
%{go_exclusivearch}

%description -n go-tools
This package contains additional toolsgraphy libraries that are developed by the
Go team but outside of the main source tree.

%prep
%setup -q -n %{repo}-%{version}

rm -rf cover
rm -rf cmd/cover
rm -rf cmd/vet

%build
%goprep %{import_path}
%gobuild ...

for tool in $(ls %{_builddir}/%{repo}-%{version}/cmd); do
  mango-doc -version %{version} %{_builddir}/%{repo}-%{version}/cmd/${tool} > %{_builddir}/%{repo}-%{version}/${tool}.1
done

%install
%goinstall
%gosrc
%gofilelist

%fdupes %{buildroot}%{_prefix}

install -D -p -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/godoc.service
install -d %{buildroot}/%{_sbindir}
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcgodoc

find . -name '*.1' -exec install -Dm644 {} %{buildroot}%{_mandir}/man1/{} \;

%pre -n go-tools
%service_add_pre godoc.service

%post -n go-tools
%service_add_post godoc.service

%preun -n go-tools
%service_del_preun godoc.service

%postun -n go-tools
%service_del_postun godoc.service

%files -f file.lst
%defattr(-,root,root,-)
%doc README LICENSE PATENTS AUTHORS CONTRIBUTORS

%files -n go-tools
%defattr(-,root,root)
%{_bindir}/benchcmp
%{_bindir}/bundle
%{_bindir}/callgraph
%{_bindir}/digraph
%{_bindir}/eg
%{_bindir}/fiximports
%{_bindir}/godex
%{_bindir}/godoc
%{_bindir}/goimports
%{_bindir}/gomvpkg
%{_bindir}/gorename
%{_bindir}/gotype
%{_bindir}/goyacc
%{_bindir}/guru
%{_bindir}/heapview
%{_bindir}/html2article
%{_bindir}/present
%{_bindir}/ssadump
%{_bindir}/stress
%{_bindir}/stringer
%{_bindir}/tip
%{_bindir}/toolstash

%{_mandir}/man1/benchcmp.1*
%{_mandir}/man1/bundle.1*
%{_mandir}/man1/callgraph.1*
%{_mandir}/man1/digraph.1*
%{_mandir}/man1/eg.1*
%{_mandir}/man1/fiximports.1*
%{_mandir}/man1/godex.1*
%{_mandir}/man1/godoc.1*
%{_mandir}/man1/goimports.1*
%{_mandir}/man1/gomvpkg.1*
%{_mandir}/man1/gorename.1*
%{_mandir}/man1/gotype.1*
%{_mandir}/man1/goyacc.1*
%{_mandir}/man1/guru.1*
%{_mandir}/man1/heapview.1*
%{_mandir}/man1/html2article.1*
%{_mandir}/man1/present.1*
%{_mandir}/man1/ssadump.1*
%{_mandir}/man1/stress.1*
%{_mandir}/man1/stringer.1*
%{_mandir}/man1/tip.1*
%{_mandir}/man1/toolstash.1*

%{_unitdir}/godoc.service
%{_sbindir}/rcgodoc

%changelog
* Tue Feb 28 2017 thipp@suse.de
- Fix requirements
- Remove duplicate files
* Tue Dec 20 2016 tboerger@suse.com
- Create a proper subpackage
* Fri Dec 16 2016 tboerger@suse.com
- Updated mango-doc dependency name
* Tue Dec 13 2016 tboerger@suse.com
- Update to version 1.4.2+git20161212.0a14ca4:
  * go/buildutil, cmd/guru: fix tests for symlinks in guru and gorename to account for windows
  * Revert "go/buildutil, cmd/guru: fix tests for symlinks in guru and gorename to account for windows."
  * Revert "go/buildutil: handle symlinks in filenames"
  * cmd/guru: avoid testing symlinks on OSes that do not support them
  * go/buildutil, cmd/guru: resolve symlinks in filenames through build.Context
  * go/internal/gccgoimporter: handle conversions in exported const values
  * go/loader: fix broken tests after context removal from testing package
  * playground/socket: deflake test, remove sleep
  * godoc: Regenerate static/static.go
  * godoc: don't select line numbers when highlighting source code
* Tue Dec 13 2016 tboerger@suse.com
- Updated service definition
* Wed Aug 17 2016 tboerger@suse.com
- Added rpmlintrc for common golang linting
* Tue Aug 16 2016 tboerger@suse.com
- Applied latest changes for golang-packaging
* Fri Jul  8 2016 tboerger@suse.com
- Refactoed spec with a new unified layout
- Dropped rpmlintrc
* Sun Mar 20 2016 bwiedemann@suse.com
- Specify version to fix build-compare
* Fri Aug 28 2015 i@marguerite.su
- Update to version 1.4.2+git20150825.b48dc8d:
  + cmd/godoc: remove obsolete vet redirect
  + imports: fix bug, where unused named import is mistaken for unnamed import.
  + cmd/tipgodoc: change capitalization of 'Authors' to be consistent
  + go/loader: fix fd leak and limit calls to ioutil.ReadDir
  + website: fix JavaScript error on website and blog in non-ES6 browsers
  + cmd/gotype: use std lib go/types instead of x/tools version
  + cmd/gotype: keep gotype working with Go1.4
- cover/vert are merged in mainline go 1.5, so strip them off.
* Sat Jul 11 2015 i@marguerite.su
- rename to golang-org-x-tools
- update version 1.4.2+git20150710.4cd43f3
- use golang-packaging for packaging
* Sat May 30 2015 i@marguerite.su
- update version 1.4.2+git20150529.8ccf558
- use update-alternatives to avoid conflict w/
  perl-Devel-Cover package
* Wed Mar 25 2015 i@marguerite.su
- add go-tools-rpmlintrc file as source2
* Tue Mar 24 2015 i@marguerite.su
- BuildRequires:  go-oauth2
* Sat Mar 21 2015 i@marguerite.su
- update version 1.4.2+git20150320.af0a448
* Sun Mar  8 2015 i@marguerite.su
- update to 1.4.2+git20150306.c327a7c
- upstream changed to github.com/golang/tools
- package name changed: go-tools
- add provides/obsoletes
* Thu Sep 18 2014 cbosdonnat@suse.com
- Updated to 1.3.1 using mercurial tip
- removed patches:
  * godoc-path-locations.patch: no longer needed all sources are in
    GOROOT or GOPATH
* Fri Oct 18 2013 speilicke@suse.com
- Initial version
